@@ -7,7 +7,7 @@ use base 'PPI::Token::Quote';
 
 use vars qw{$VERSION %quotes %sections};
 BEGIN {
-	$VERSION = '0.811';
+	$VERSION = '0.812';
 
 	# For each quote type, the extra fields that should be set.
 	# This should give us faster initialization.
@@ -59,7 +59,7 @@ sub new {
 	$self;
 }
 
-sub fill {
+sub _fill {
 	my $class = shift;
 	my $t = shift;
 	my $self = $t->{token} or return undef;
